@@ -1,21 +1,19 @@
+from .genomic_interval import GenomicInterval
 from lhc.binf.sequence.reverse_complement import reverse_complement
 
 
-class NestedGenomicInterval(object):
-
-    def __init__(self, intervals=None, chr=None, strand='+', data=None):
-        self.chr = intervals[0].chr if len(intervals) > 0 and chr is None else chr
-        self.intervals = [] if intervals is None else intervals
-        self.strand = strand
-        self.data = data
+class NestedGenomicInterval(GenomicInterval):
+    def __init__(self, chromosome, start, stop, *, strand='+', data=None):
+        super().__init__(chromosome, start, stop, strand=strand, data=data)
+        self.children = []
 
     def __len__(self):
-        return sum(len(child) for child in self.intervals)
+        return sum(len(child) for child in self.children)
 
     # Position functions
     
     def get_abs_pos(self, pos):
-        intervals = self.intervals if self.strand == '+' else reversed(self.intervals)
+        intervals = self.children if self.strand == '+' else reversed(self.children)
         fr = 0
         for interval in intervals:
             length = len(interval)
@@ -26,7 +24,7 @@ class NestedGenomicInterval(object):
     
     def get_rel_pos(self, pos, types=None):
         rel_pos = 0
-        intervals = iter(self.intervals) if self.strand == '+' else reversed(self.intervals)
+        intervals = iter(self.children) if self.strand == '+' else reversed(self.children)
         for interval in intervals:
             if types is not None and interval.type not in types:
                 continue
@@ -38,13 +36,13 @@ class NestedGenomicInterval(object):
     # Sequence functions
     
     def get_sub_seq(self, sequence_set):
-        res = ''.join(interval.get_sub_seq(sequence_set) for interval in self.intervals)
+        res = ''.join(interval.get_sub_seq(sequence_set) for interval in self.children)
         return res if self.strand == '+' else reverse_complement(res)
 
     def get_5p(self):
-        return self.intervals[0].get_5p() if self.strand == '+' else\
-            self.intervals[-1].get_5p()
+        return self.children[0].get_5p() if self.strand == '+' else\
+            self.children[-1].get_5p()
 
     def get_3p(self):
-        return self.intervals[-1].get_3p() if self.strand == '+' else\
-            self.intervals[0].get_3p()
+        return self.children[-1].get_3p() if self.strand == '+' else\
+            self.children[0].get_3p()
